Measurement techniques
======================

Liquid scintillation counting (LSC)
-----------------------------------

**Liquid scintillation counting (LSC)** is a measuring technique for the determination of low energetic β-emitters.
It is capable to detect all processes emitting light photons, both, directly and indirectly.
Therefore, it is also applicable for high energetic β-emitters, electron capture nuclides and α-emitters.

This technique involves mixing a radioactive sample with a scintillation cocktail,
which emits light when it interacts with radiation.
The emitted light is then measured to determine the activity of the radionuclide, using photomultiplier tubes.
This method provides very high efficiency due to the intimate contact between sample and scintillator.
It also provides a high degree of accuracy and is suitable for a wide range of radionuclides

In radionuclide metrology, LSC has been successfully employed for the standardization of many radionuclides for decades.
There are two methods to do this: the CIEMAT/NIST efficiency tracing and the triple-to-double coincidence ratio (TDCR).
Both methods are accepted by Section II of the Consultative Committee for Ionization Radiation (CCIR) in
Bureau International des Poids et Mesures (BIPM) for the international reference system (SIR) for pure β-emitters.

Find more details about the LSC technique in this
`academic article by R. Broda et al. <http://doi.org/10.1088/0026-1394/44/4/S06>`_
For a more user-friendly approach, check this
`Introduction to liquid scintillation <https://www.hidex.com/hidex-methods/introduction/triple-coincidence-applications>`_.

Triple-to-double coincidence ratio (TDCR)
-----------------------------------------

The **triple-to-double coincidence ratio (TDCR)** method is a fundamental method in liquid scintillation counting.
It is an absolute method for the determination of the activity of β- and EC-decaying radionuclides
in liquid scintillator medium.

It is a universal method applicable for both chemical and color quenching, for aqueous and organic samples and
for different cocktails and range of isotopes.
Unlike other methods, this method does not need external or internal standard sources.

The method itself is based on a physical and statistical model of the distribution of scintillation photons and
their detection probability in a three-photomultiplier (PMT) counter.
It combines experimental data with theoretical calculations of the detector efficiency.
The knowledge of the radionuclide decay scheme data is precondition.

Find more details about the TDCR method in this
`academic article by R. Broda <https://doi.org/10.1016/S0969-8043(03)00056-3>`_.
For a more user-friendly approach, check this
`Introduction to liquid scintillation <https://www.hidex.com/hidex-methods/introduction/triple-coincidence-applications>`_.
